"""
Calculates how many % the Golgi is of the total cell
"""

import skimage.external.tifffile as tiff
from skimage.filters import threshold_otsu
import numpy as np
import glob
import os
import sys
import pandas as pd
import datetime


def parseImgName(imgName):
    nameArray = imgName.split('_')

    if "Ctrl1" in nameArray[0]:
        condition = "14197"
    elif "Ctrl2" in nameArray[0]:
        condition = "14242"
    elif "Stx51" in nameArray[0]:
        condition = "14230"
    elif "Stx52" in nameArray[0]:
        condition = "14235"
    elif "Stx1" in nameArray[0]:
        condition = "14230"
    elif "Stx2" in nameArray[0]:
        condition = "14235"
    elif "14197" in nameArray[0]:
        condition = "14197"
    elif "14242" in nameArray[0]:
        condition = "14242"
    elif "14230" in nameArray[0]:
        condition = "14230"
    elif "14235" in nameArray[0]:
        condition = "14235"
    elif "Ctrl" in nameArray[0]:
        condition = "Ctrl"
    elif "Stx5" in nameArray[0]:
        condition = "Stx5"
    else:
        condition = "Unknown"

    if nameArray[1] in ["gm130", "Giantin", "TGN46"]:
        marker = nameArray[1]
    else:
        marker = nameArray[3]

    img = nameArray[-2]
    cell = nameArray[-1][4:]

    return condition, marker, img, cell


def measureGolgiArea(img, golgiChan=0, bfChan=3):
    '''
    Measure number of pixels in Golgi channel and divide by number of pixels in brightfield channel.
    Exterior of cell should be 0 after creating the single cell images.
    '''

    with tiff.TiffFile(img) as tif:
        images = tif.asarray()

    imgName = os.path.basename(img).split('.tif')[0]

    # condition, marker, img, cell = parseImgName(imgName)

    golgiArray = images[golgiChan]
    bfArray = images[bfChan]

    golgiBinary = golgiArray >= threshold_otsu(golgiArray)
    peripheralBinary = (golgiArray < threshold_otsu(golgiArray)) & (golgiArray > 0)

    golgiPixels = golgiBinary.sum()
    golgiMFI = np.nanmean(golgiArray[golgiBinary])
    peripheralMFI = np.nanmean(golgiArray[peripheralBinary])
    peripheralPixels = peripheralBinary.sum()
    bfPixels = (bfArray > 0).sum()

    # return imgName, condition, marker, img, cell, ((golgiPixels / bfPixels) * 100), golgiMFI, ((peripheralPixels / bfPixels) * 100), peripheralMFI
    return imgName, ((golgiPixels / bfPixels) * 100), golgiMFI, ((peripheralPixels / bfPixels) * 100), peripheralMFI

# tiffList = glob.glob(sys.argv[1] + "/*.tif")
# os.chdir(sys.argv[1])
# outputList = [measureGolgiArea(img) for img in tiffList]
# # output_df = pd.DataFrame(outputList, columns=['Name', 'Condition', 'Marker', 'Img', 'Cell', 'GolgiArea','GolgiIntensity', 'PeripheralArea', 'PeripheralIntensity'])
# output_df = pd.DataFrame(outputList, columns=['Name', 'GolgiArea','GolgiIntensity', 'PeripheralArea', 'PeripheralIntensity'])
# now = datetime.datetime.now()
# today = now.strftime("%y%m%d")
# output_df.to_csv(f"{today}.csv", index=False)