# This time Ctrl and Stx5 are pooled
library(tidyverse)
library(ggpubr)

df <- read.csv("../../processed/fibroblasts/colocalization/190806_coloc_combined.csv")
df$Line <- factor(df$Line, levels = c("14197", "14242", "14230", "14235"))
df$Condition <- ifelse(df$Line == "14197" | df$Line == "14242", 'Ctrl',
                    ifelse(df$Line == "14230" | df$Line == "14235", 'Stx5M55V', NA))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))

}

generate_coloc_plot <- function(data, marker) {
    p <- data %>%
        filter(Marker == marker) %>%
        ggplot(., aes(x = Condition, y = Pearson)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        ylab("Pearson Correlation Coefficient") +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        scale_y_continuous( breaks=c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0), limits=c(-0.2, 1.1)) +
        theme(legend.position = "none")
    
    ggsave(sprintf("%s.pdf", marker), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")

}

for (marker in levels(df$Marker)) {
    generate_coloc_plot(df, marker)
}

table_vals <- df %>%
    group_by(Marker, Condition) %>%
        summarise(N = length(Pearson),
            Median = median(Pearson),
            Mean = mean(Pearson),
            SD = sd(Pearson),
            Var = var(Pearson))

write.table(table_vals, "Coloc_vals.txt")

ttest_chars <- capture.output(for (marker in levels(df$Marker)) {
    ttest <- df %>%
        filter(Marker == marker) %>%
        t.test(Pearson ~ Condition, data = ., var.equal = TRUE)
    print(marker)
    print(ttest)

    }       
)

writeLines(ttest_chars, "Coloc_stats.txt")