library(tidyverse)
library(ggpubr)


df <- read.csv("../../processed/HeLa/FLIM/191017_FLIMCHX.csv")

levels(df$Combination) <- list(Donor = "donor", Bet1L = "bet1l", Vamp8 = "vamp8")
df$Isoform <- factor(df$Isoform, levels = c("Stx5S", "Stx5L"))

df <- df %>%
    rowwise() %>%
    mutate(Experiment = strsplit(as.character(CellIdent), " ")[[1]][1])   

    intmag95 <- function(x) {
        sem <- sd(x) / sqrt(length(x))
        t <- qt(0.975, df = length(x) - 1)
        return(sem * t)
    }

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

expMeanDf <- df %>%
    ungroup() %>%
    group_by(Isoform, Combination, Timepoint, Experiment) %>%
    summarise(avg = mean(Lifetime..τ..1.ns))

generate_avg_plot <- function(data, combination, timepoint) {
    p <- expMeanDf %>%
        filter(Combination %in% c("Donor", combination) & Timepoint == timepoint) %>%
        ggplot(., aes(x = Combination, y = avg)) +
        #geom_jitter(aes(fill = Isoform, colour = Isoform), stroke = 0, alpha = 0.5, position = position_jitterdodge(jitter.width = 0.2, dodge.width = 1)) +
        geom_point(aes(fill = Isoform, colour = Isoform), stroke = 0, alpha = 0.3, position = position_dodge(1)) +
        stat_summary(aes(colour = Isoform), fun.data = summary_ci, geom = "point", shape = 95, size = 5, position=position_dodge(1), show.legend=FALSE) +
        ylab("Stx5-mCitrine lifetime (ns)")  +
        scale_y_continuous(breaks=c(2.0, 2.2, 2.4, 2.6, 2.8, 3.0, 3.2), limits=c(1.8, 3.2)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        #ylim(0.0, 1.2) +
        theme(axis.text.x = element_text(angle = 90, hjust = 0.5, vjust = 0.5), legend.position = "none")

    ggsave(sprintf("%s_%s_avg.pdf", timepoint, combination), p, device = cairo_pdf, dpi = 600, width = 42.5, height = 56.00, units = "mm")
   
}

for (timepoint in levels(df$Timepoint)) {
    for (combination in levels(df$Combination)) {
        generate_avg_plot(df, combination, timepoint)
    }
}
