library(tidyverse)

df <- read.csv("../../processed/fibroblasts/morphology/190905_TotalMorphologyNorm.csv")
df$Line <- factor(df$Line, levels = c("14197", "14242", "14230", "14235"))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))
df$log2Value <- log2(df$Value)

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

generate_morphology_plot <- function(data, marker) {
    p <- data %>%
        filter(Marker == marker) %>%
        ggplot(., aes(x = Condition, y = log2Value)) +
        geom_violin(trim = TRUE, aes(fill= Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        labs(y = sprintf("log2(Relative %s intensity)", marker)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        theme(legend.position = "none")

    ggsave(sprintf("%s.pdf", marker), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

for (marker in levels(df$Marker)) {
    generate_morphology_plot(df, marker)
}

table_vals <- df %>%
    group_by(Marker, Condition) %>%
        summarise(N = length(Value_norm),
            Median = median(Value_norm),
            Mean = mean(Value_norm),
            SD = sd(Value_norm),
            Var = var(Value_norm),
            log2Median = median(log2Value),
            log2Mean = mean(log2Value),
            log2SD = sd(log2Value),
            log2Var = var(log2Value))

write.table(table_vals, "Morphology_vals.txt")

ttest_chars <- capture.output(for (marker in levels(df$Marker)) {
    ttest <- df %>%
        filter(Marker == marker) %>%
        t.test(log2Value ~ Condition, data = ., var.equal = TRUE)
    print(marker)
    print(ttest)

    }       
)

writeLines(ttest_chars, "Morphology_stats.txt")