library(tidyverse)
library(RColorBrewer)

M557M559 <- read.csv("../../processed/HeLa/BFA/191023_M557M559.csv", sep = ';')
M592B <- read.csv("../../processed/HeLa/BFA/191023_M592B.csv", sep = ';')

df <- rbind(M557M559, M592B)

df$Line <- factor(df$Line, levels = c("HeLa", "B1A7", "C1F4"))
levels(df$Condition) = list("WT" = "WT", "Stx5ΔL" = "Stx5deltaL")
df$log2Value <- log2(df$Value)

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

# deltaL colours
deltaL_palette <- brewer.pal(8, "Dark2")[c(1,3)]

generate_bfa_plot <- function(data) {
    p <- data %>%
        filter(Treatment == "BFA") %>%
        ggplot(., aes(x = Condition, y = log2Value)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        ylab(expression("log"[2]*"(Relative GALNT2 intensity)")) +
        #scale_color_brewer(palette = "Dark2", values = c(1,3)) +
        scale_color_manual(values = deltaL_palette) +
        scale_fill_manual(values = deltaL_palette) +
        scale_y_continuous(limits=c(-2.5, 1.0)) +
        #scale_fill_brewer(palette = "Dark2", values = c(1,3)) +
        theme(legend.position = "none")

    ggsave("BFA.pdf", p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

table_vals <- df %>%
    filter(Treatment == "BFA") %>%
    group_by(Condition) %>%
        summarise(N = length(Value),
            Median = median(Value),
            Mean = mean(Value),
            SD = sd(Value),
            Var = var(Value),
            log2Median = median(log2Value),
            log2Mean = mean(log2Value),
            log2SD = sd(log2Value),
            log2Var = var(log2Value))

write.table(table_vals, "BFA_vals.txt")

ttest <- df %>%
            filter(Treatment == "BFA") %>%
            t.test(log2Value ~ Condition, data = ., var.equal = TRUE)

ttest_chars <- capture.output(print(ttest))

writeLines(ttest_chars, "BFA_stats.txt")

generate_bfa_plot(df)