library(tidyverse)

source("../../../../../R_themes//myTheme.R")

PL0512 <- read.csv("raw_data/191022_PL051.2_log10.csv", sep = ';')
PL0513 <- read.csv("raw_data/191022_PL051.3_log10.csv", sep = ';')

df <- rbind(PL0512, PL0513)
df$Line <- factor(df$Line, levels = c("14197", "14242", "14230", "14235"))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

generate_bfa_plot <- function(data) {
    p <- data %>%
        filter(Treatment == "BFA") %>%
        ggplot(., aes(x = Condition, y = Log10_norm)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        ylab(expression("Relative GALNT2 log"[10]*"(intensity)")) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
       # scale_y_continuous(limits=c(-2.5, 1.0)) +
        mytheme +
        theme(legend.position = "none")

    ggsave("BFA.pdf", p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

table_vals <- df %>%
    filter(Treatment == "BFA") %>%
    group_by(Condition) %>%
        summarise(N = length(Log10_norm),
            Median = median(Log10_norm),
            Mean = mean(Log10_norm),
            SD = sd(Log10_norm),
            Var = var(Log10_norm))

write.table(table_vals, "BFA_vals.txt")

ttest <- df %>%
            filter(Treatment == "BFA") %>%
            t.test(Log10_norm ~ Condition, data = ., var.equal = TRUE)

ttest_chars <- capture.output(print(ttest))

writeLines(ttest_chars, "BFA_stats.txt")

generate_bfa_plot(df)
