# This time Ctrl and Stx5 are pooled
source("../../../../../../R_themes//myTheme.R")
library(tidyverse)
library(ggpubr)

df <- read.csv("200916_lectinlog10norm.csv", sep = ";")
df$Line <- factor(df$Line, levels = c("14197", "14242", "14230", "14235"))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))
df$Lectin <- factor(df$Lectin, levels = c("PNA", "SNA"))
df$Experiment <- factor(df$Experiment, levels = c("PL049_2", "PL049_3"))

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))

}

generate_lectin_plot <- function(data, lectin) {

    
    stats_results <- data %>%
        filter(Lectin == lectin) %>%
        t.test(Value ~ Condition, data = ., var.equal = TRUE)


    p <- data %>%
        filter(Lectin == lectin) %>%
        ggplot(., aes(x = Condition, y = Value)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        #labs(y = bquote(""~log[2]~"Relative"~.(lectin)~"intensity (AU)")) +
        labs(y = sprintf("Relative %s log10 intensity (AU)", lectin)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        #ylim(0.0, 1.2) +
        mytheme +
        theme(legend.position = "none")

    ggsave(sprintf("%s_pooled.pdf", lectin), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")

    chars <- capture.output(print(stats_results))
    writeLines(chars, con = file(sprintf("%s_pooled_stats.txt", lectin)))
}

for (lectin in levels(df$Lectin)) {
    generate_lectin_plot(df, lectin)
}

table_vals <- df %>%
        group_by(Lectin, Condition) %>%
        summarise(N = length(Value),
            Median = median(Value),
            Mean = mean(Value),
            SD = sd(Value),
            Var = var(Value))

write.table(table_vals, "Pooled_Lectin_vals.txt")
