library(tidyverse)
library(ggpubr)
library(RColorBrewer)
library(rstatix)
source("../../../../../R_themes//myTheme.R")

df <- read.csv("DeltaLLectinData.csv", sep = ",", stringsAsFactors = TRUE)
levels(df$Condition) = list("WT" = "WT", "Stx5ΔL" = "Stx5deltaL")
df$Line <- factor(df$Line, levels = c("HeLa", "B1A7", "C1F4"))
df$Experiment <- factor(df$Experiment, levels=c("200909", "200911", "200917", "200918"))

data_summary <- function(x) {
    m <- mean(x)
    ymin <- m - (sd(x) / sqrt(length(x)))
    ymax <- m + (sd(x) / sqrt(length(x)))
    return(c(y = m, ymin = ymin, ymax = ymax))
}

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

deltaL_palette <- brewer.pal(8, "Dark2")[c(1,3)]


generate_facs_plot <- function(data, lectin) {
    p <- data %>%
            filter(Lectin == lectin) %>%
                ggplot(., aes(x= Condition, y = Value)) +
                geom_point(aes(fill = Condition, colour = Condition), stroke = 0, alpha = 0.3, position = position_dodge(1)) +
                stat_summary(aes(colour = Condition), fun.data = summary_ci, geom = "point", shape = 95, size = 5, position=position_dodge(1), show.legend=FALSE) +
                ylab(sprintf("Relative %s log10(intensity) (AU)", lectin)) +
                scale_color_manual(values = deltaL_palette) +
                scale_fill_manual(values = deltaL_palette) +
                #ylim(0.0, 1.2) +
                mytheme +
                theme(axis.text.x = element_text(angle = 90, hjust = 0.5, vjust = 0.5), legend.position = "none")
    ggsave(sprintf("%s_facs.pdf", lectin), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

for (lectin in levels(df$Lectin)) {
    generate_facs_plot(df, lectin)
}

stats_df <- df %>%
    group_by(Lectin) %>%
    t_test(Value ~ Condition)

write.csv(stats_df, "deltaLLectinStats.csv")