# This time Ctrl and Stx5 are pooled

library(tidyverse)
library(ggpubr)
library(scales)

source("../../../../../R_themes//myTheme.R")

df <- read.csv("raw_data/20201028.csv", sep = ",")
exp20200720 <- read.csv("raw_data/20200720.csv", sep = ";")
# df <- rbind(exp20201028, exp20200720)

df$Line <- factor(df$Line, levels = c("14197", "14242", "14230", "14235"))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))
df$Marker <- factor(df$Marker, levels = c("GM130", "PDI"))


intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))

}

generate_coloc_plot <- function(data, marker) {
    p <- data %>%
        filter(Marker == marker) %>%
        ggplot(., aes(x = Condition, y = Value)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        ylab(sprintf("Pearson Correlation Coefficient\n %s", marker)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        scale_y_continuous( breaks=c(0.0, 0.2, 0.4, 0.6, 0.8, 1.0), limits=c(-0.2, 1.1)) +
        mytheme +
        theme(legend.position = "none")


    
    ggsave(sprintf("%s.pdf", marker), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")


}

for (marker in levels(df$Marker)) {
    generate_coloc_plot(df, marker)
}


ttest_chars <- capture.output(
    for (marker in levels(df$Marker)) {
        ttest <- df %>%
            filter(Marker == marker) %>%
            t.test(Value ~ Condition, data = ., var.equal = TRUE)
        print(marker)
        print(ttest)
    }       
)


writeLines(ttest_chars, con = file("Stx5L_stats.txt"))

chars <- capture.output(for (marker in levels(df$Marker)) {
        print(marker)
        print(df %>%
            filter(Marker == marker) %>%
            group_by(Condition) %>%
            summarise(N = length(Value),
                     Median = median(Value),
                     Mean = mean(Value),
                     SD = sd(Value),
                     Var = var(Value)))
    }
)

writeLines(chars, con = file("Stx5L_vals.txt"))
