# This time Ctrl and Stx5 are pooled
source("../../../../../R_themes//myTheme.R")
library(tidyverse)
library(rstatix)

df <- read.csv("201116_VSVGnorm.csv", sep = ",")
df$Line <- factor(df$Line, levels = c("14242", "14230"))
df$Condition <- factor(df$Condition, levels = c("Ctrl", "Stx5M55V"))

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))

}

generate_vsvg_plot <- function(data) {

    p <- data %>%
        ggplot(., aes(x = Condition, y = Value)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        labs(y = "VSVG Ratio Surface:Intracellular") +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        mytheme +
        theme(legend.position = "none")

    ggsave("VSVG.pdf", p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

generate_vsvg_plot(df)

stats_df <- df %>%
    t_test(Value ~ Condition)
    
write.csv(stats_df, "VSVG_stats.csv")
