# This time Ctrl and Stx5 are pooled
source("../../../../../R_themes//myTheme.R")
library(tidyverse)
library(ggpubr)
library(RColorBrewer)
library(rstatix)

df <- read.csv("201210_FibDeltaL_norm.csv", sep = ",", stringsAsFactors = TRUE)
df$Condition <- factor(df$Condition, levels = c("Ctrl" = "Ctrl", "Stx5ΔL" = "Stx5deltaL"))
df$Lectin <- factor(df$Lectin, levels = c("PNA", "SNA"))

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))

}

deltaL_palette <- brewer.pal(8, "Dark2")[c(1,3)]


generate_lectin_plot <- function(data, lectin) {

    p <- data %>%
        filter(Lectin == lectin) %>%
        ggplot(., aes(x = Condition, y = Value)) +
        geom_violin(trim = TRUE, aes(fill = Condition, color = Condition)) +
        stat_summary(fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        #labs(y = bquote(""~log[2]~"Relative"~.(lectin)~"intensity (AU)")) +
        labs(y = sprintf("Relative %s log10 intensity (AU)", lectin)) +
        scale_color_manual(values = deltaL_palette) +
        scale_fill_manual(values = deltaL_palette) +
        #ylim(0.0, 1.2) +
        mytheme +
        theme(legend.position = "none")

    ggsave(sprintf("%s_deltaL.pdf", lectin), p, device = cairo_pdf, dpi = 600, width = 26.5, height = 56.00, units = "mm")
}

for (lectin in levels(df$Lectin)) {
    generate_lectin_plot(df, lectin)
}

table_vals <- df %>%
        group_by(Lectin, Condition) %>%
        summarise(N = length(Value),
            Median = median(Value),
            Mean = mean(Value),
            SD = sd(Value),
            Var = var(Value))

write.table(table_vals, "Pooled_Lectin_vals.txt")

stats_df <- df %>%
    group_by(Lectin) %>%
    t_test(Value ~ Condition)

write.csv(stats_df, "deltaLLectinStats.csv")