library(tidyverse)
library(ggpubr)
library(rstatix)

source("../../../../R_themes/myTheme.R")

df210520<- read.csv("CDS/210520 FLIM Stx5 CDS_output.csv", stringsAsFactors = TRUE)
df210521<- read.csv("CDS/210521 FLIM Stx5 CDS_output.csv", stringsAsFactors = TRUE)
df210603 <- read.csv("CDS/210603 FLIM Stx5 CDS_output.csv", stringsAsFactors = TRUE)
df210610 <- read.csv("CDS/210610 FLIM Stx5 CDS_output.csv", stringsAsFactors = TRUE)
df210611 <- read.csv("CDS/210611 Stx5 FLIM CDS_output.csv", stringsAsFactors = TRUE)
df210617 <- read.csv("CDS/210617 Stx5 FLIM CDS_output.csv", stringsAsFactors = TRUE)
df210618 <- read.csv("CDS/210618 Stx5 FLIM CDS_output.csv", stringsAsFactors = TRUE)
df210625 <- read.csv("CDS/210625 Stx5 FLIM CDS_output.csv", stringsAsFactors = TRUE)

df <- rbind(df210520, df210521)
df <- rbind(df, df210603)
df <- rbind(df, df210610)
df <- rbind(df, df210611)
df <- rbind(df, df210617)
df <- rbind(df, df210618)
df <- rbind(df, df210625)

df$Experiment <- factor(df$Experiment)

data_summary <- function(x) {
    m <- mean(x)
    ymin <- m - (sd(x) / sqrt(length(x)))
    ymax <- m + (sd(x) / sqrt(length(x)))
    return(c(y = m, ymin = ymin, ymax = ymax))
}

intmag95 <- function(x) {
    sem <- sd(x) / sqrt(length(x))
    t <- qt(0.975, df = length(x) - 1)
    return(sem * t)
}

summary_ci <- function(x) {
    m <- mean(x)
    ymin <- m - intmag95(x)
    ymax <- m + intmag95(x)
    return(c(y = m, ymin = ymin, ymax = ymax))
}

levels(df$Combination) <- list(Donor = "donor", Bet1L = "bet1l", Vamp8 = "vamp8")
df$Isoform <- factor(df$Isoform, levels = c("Stx5S", "Stx5L"))


df <- df %>%
        unite(col = "Label", c('Isoform', 'Condition', 'Timepoint'), remove = FALSE)
df$Label <- factor(df$Label, levels = c("Stx5S_Donor_ER", "Stx5S_Donor_Golgi", "Stx5L_Donor_ER", "Stx5L_Donor_Golgi",
                                            "Stx5S_Bet1L_ER", "Stx5S_Bet1L_Golgi", "Stx5L_Bet1L_ER", "Stx5L_Bet1L_Golgi",
                                            "Stx5S_Vamp8_ER", "Stx5S_Vamp8_Golgi", "Stx5L_Vamp8_ER", "Stx5L_Vamp8_Golgi"
                                            ))

generate_flim_plot <- function(data, condition, timepoint) {
    stats_results <- data %>%
        filter(Condition %in% c("Donor", condition) & Timepoint == timepoint) %>%
        compare_means(Value ~ Label, data = ., method = "t.test", p.adjust.method = "bonferroni")
    stats_compare_df <- stats_results %>%
        filter(p.signif != "ns") %>%
        select(group1, group2) %>%
        rowwise() %>%
        do(comparisons = c(.$group1, .$group2))

    data_values <- data %>%
        filter(Condition %in% c("Donor", condition) & Timepoint == timepoint) %>%
        group_by(Isoform, Condition, Timepoint) %>%
        summarize(avg = mean(Value),
                se = sd(Value) / sqrt(n()),
                ci = intmag95(Value)) %>%
        ungroup()

    p <- data %>%
        filter(Condition %in% c("Donor", condition) & Timepoint == timepoint) %>%
        ggplot(., aes(x = Label, y = Value)) +
        geom_jitter(aes(color = Isoform, fill = Isoform), alpha=0.2, stroke=0, width=0.1) +
        #geom_violin(trim = TRUE, aes(color = Isoform, fill = Isoform), lwd=1, position=position_dodge(1)) +
        stat_summary(aes(color = Isoform, fill = Isoform), fun.data = data_summary, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        #stat_summary(aes(color = Isoform, fill = Isoform), fun.data = data_summary, geom = "pointrange", shape = 20, size = 0.3, fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        ylab("Lifetime (ns)")  +
        scale_x_discrete(labels=c("Donor", condition)) +
        #coord_cartesian(ylim = c(1.8, 3.2)) +
        #stat_compare_means(comparisons = stats_compare_df$comparisons, method = "t.test", label = "p.signif", tip.length = 0.01, step.increase = 0.05, bracket.size = 0.1, hide.ns = TRUE, size = 1) +
        scale_y_continuous(breaks=c(2.0, 2.2, 2.4, 2.6, 2.8, 3.0, 3.2), limits=c(1.8, 3.2)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        #ggtitle(sprintf("%s %s", timepoint, combination)) +
        mytheme +
        theme(legend.position = "none")
        #theme(plot.margin = unit(c(2.1,0.2,0.1,0.1),"cm"))

        #theme(plot.title = element_text(hjust = 0.5)
    
    #p$layers[[3]]$aes_params$textsize <- 1


    p2 <- data %>%
        filter(Condition %in% c("Donor", condition) & Timepoint == timepoint) %>%
        ggplot(., aes(x = Condition, y = Value)) +
        geom_violin(trim = TRUE, aes(color = Isoform, fill = Isoform), lwd=1, position=position_dodge(1)) +
        stat_summary(aes(color = Isoform, fill = Isoform), fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
        #stat_compare_means(comparisons = stats_compare_df$comparisons, method = "t.test", label = "p.signif", tip.length = 0.01, step.increase = 0.1, hide.ns = TRUE) +
        ylab("Lifetime (ns)") +
        scale_x_discrete(labels=c("Donor", condition)) +
        scale_y_continuous(breaks=c(2.0, 2.2, 2.4, 2.6, 2.8, 3.0, 3.2), limits=c(1.8, 3.2)) +
        scale_color_brewer(palette = "Dark2") +
        scale_fill_brewer(palette = "Dark2") +
        #ggtitle(sprintf("%s %s", timepoint, combination)) +
        mytheme +
        theme(legend.position = "none")
        
        #theme(plot.title = element_text(hjust = 0.5))

    print(sprintf("Plotted %s %s", timepoint, condition))
    ggsave(sprintf("%s_%s.pdf", timepoint, condition), p, device = cairo_pdf, dpi = 600, width = 42.5, height = 56.00, units = "mm")
    ggsave(sprintf("%s_%s_axis.pdf", timepoint, condition), p2, device = cairo_pdf, dpi = 600, width = 42.5, height = 56.00, units = "mm")
    write.table(stats_results, sprintf("%s_%s_stats.txt", timepoint, condition))
    write.table(data_values, sprintf("%s_%s_values.txt", timepoint, condition))
}

for (timepoint in levels(df$Timepoint)) {
    for (condition in levels(df$Condition)) {
        generate_flim_plot(df, condition, timepoint)
    }
}


n_table <- df %>%
            group_by(Label) %>%
            count()

write.table(n_table, "FLIM_N.txt")

meanvals <- df%>%
    group_by(Condition, Timepoint, Isoform, Experiment) %>%
    summarise(mean = mean(Value))

p_mean <- meanvals %>%
    filter(Condition %in% c("Donor", "Bet1L") & Timepoint == "Golgi") %>%
    ggplot(., aes(x = Condition, y = mean)) +
    # geom_violin(trim = TRUE, aes(color = Isoform, fill = Isoform), lwd=1, position=position_dodge(1)) +
    geom_point(aes(color = Isoform, fill = Isoform), position = position_dodge((1))) +
    stat_summary(aes(color = Isoform, fill = Isoform), fun.data = summary_ci, geom = "pointrange", shape = 20, size = 0.3, colour = "gray18", fatten = 0.2, position=position_dodge(1), show.legend=FALSE) +
    #stat_compare_means(comparisons = stats_compare_df$comparisons, method = "t.test", label = "p.signif", tip.length = 0.01, step.increase = 0.1, hide.ns = TRUE) +
    ylab("Lifetime (ns)") +
    scale_x_discrete(labels=c("Donor", condition)) +
    scale_y_continuous(breaks=c(2.0, 2.2, 2.4, 2.6, 2.8, 3.0, 3.2), limits=c(1.8, 3.2)) +
    scale_color_brewer(palette = "Dark2") +
    scale_fill_brewer(palette = "Dark2") +
    #ggtitle(sprintf("%s %s", timepoint, combination)) +
    mytheme +
    theme(legend.position = "none")

meanvals %>% ungroup() %>% filter(Timepoint == "Golgi" & Condition == "Bet1L") %>% t_test(mean ~ Isoform, paired = TRUE)

meanvals %>% ungroup() %>% filter(Timepoint == "Golgi" & Condition == "VAMP8") %>% t_test(mean ~ Isoform, paired = TRUE)
